pub struct Cli {
pub interval: Option<Duration>,
pub run_times: u64,
pub delimiter: String,
pub data_unit: DataUnit,
pub cmd: CliCommand,
pub fmt: Option<String>,
}Expand description
Dead simple CLI program to query information about system and hardware. Basically a CLI wrapper over the sysinfo Rust crate.
Fields
interval: Option<Duration>Interval between commands, ignored if –run_times/-n is 1. For format see https://docs.rs/humantime/2.1.0/humantime/fn.parse_duration.html.
run_times: u64How many times to run the command. Specifying 0 will cause commands to run infinitely until the user manually terminates the program.
delimiter: StringDelimiter used for separating responses. Also used by list-cpus and list-sensors commands.
data_unit: DataUnitThe unit of information used by memory, swap, drive, and network commands.
cmd: CliCommandfmt: Option<String>String with format specifiers which will be replaced by actual values. Syntax for format
specifiers is %<SPECIFIER>%. To output the literal percent sign, write %%. If the specifier
does not exist, a corresponding error is reported. Any supplied queries to the commands are
ignored. The case does not matter (%MAC-AddREss% = %mac-address%).